==> EntitySyncer-0.0.5-sources.jar: org/openzen/entitysyncer/live/field/LiveFloatField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveFloatField extends LiveBaseField implements LiveFloat {
	private float value;
	
	public LiveFloatField(float value) {
		this.value = value;
	}
	
	@Override
	public float get() {
		return value;
	}
	
	public void set(float value) {
		this.value = value;
		publish();
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public int asIntValue() {
		return (int) value;
	}

	@Override
	public long asLongValue() {
		return (long) value;
	}
	
	@Override
	public LiveFloat asFloat() {
		return this;
	}

	@Override
	public float asFloatValue() {
		return value;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Float.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast int to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set(value);
	}

	@Override
	public void setFloat(float value) {
		set(value);
	}

	@Override
	public void setDouble(double value) {
		set((float) value);
	}

	@Override
	public void setString(String value) {
		set(Float.parseFloat(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to float");
	}
}

==> EntitySyncer-0.0.7-sources.jar: org/openzen/entitysyncer/live/field/LiveFloatField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.structured.StructuredObject;
import org.openzen.entitysyncer.structured.definition.FloatFieldType;
import org.openzen.entitysyncer.structured.definition.StructuredFieldType;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveFloatField extends LiveBaseNumberField implements LiveFloat {
	private float value;
	
	public LiveFloatField(float value) {
		this.value = value;
	}
	
	@Override
	public float get() {
		return value;
	}
	
	public void set(float value) {
		this.value = value;
		publish();
	}
	
	@Override
	public void clear() {
		set(0);
	}
	
	@Override
	public StructuredFieldType getType() {
		return FloatFieldType.INSTANCE;
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public int asIntValue() {
		return (int) value;
	}

	@Override
	public long asLongValue() {
		return (long) value;
	}
	
	@Override
	public LiveFloat asFloat() {
		return this;
	}

	@Override
	public float asFloatValue() {
		return value;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Float.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast int to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set(value);
	}

	@Override
	public void setFloat(float value) {
		set(value);
	}

	@Override
	public void setDouble(double value) {
		set((float) value);
	}

	@Override
	public void setString(String value) {
		set(Float.parseFloat(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to float");
	}
}
